@@ -35,10 +35,11 @@ BASE_TEMPLATE = "invenio_theme_tuw/page.html"
 THEME_FRONTPAGE_TEMPLATE = "invenio_theme_tuw/frontpage.html"
 THEME_HEADER_TEMPLATE = "invenio_theme_tuw/header.html"
 THEME_FOOTER_TEMPLATE = "invenio_theme_tuw/footer.html"
+THEME_JAVASCRIPT_TEMPLATE = "invenio_theme_tuw/javascript.html"
+THEME_ERROR_TEMPLATE = "invenio_theme_tuw/page_error.html"
 
 # Header logo
 THEME_LOGO = "images/TU_Signet_white.png"
-
 INSTANCE_THEME_FILE = "less/invenio_theme_tuw/theme.less"
 
 # Override the Invenio-OAuthClient login form
